import useSettingsStore from '@/settings/useSettingsStore'
import { defineComponent, Transition } from 'vue'
import useSearchStore from './useSearchStore'
import useSearchConfigStore from './useSearchConfigStore'
import SearchConfig from './SearchConfig'
import SearchHistory from './SearchHistory'
import SearchSuggestion from './SearchSuggestion'

export default defineComponent(() => {
  const settings = useSettingsStore()
  const search = useSearchStore()
  const searchConfig = useSearchConfigStore()
  return () => (
    <div
      class="relative"
      style={{
        width: settings.state.searchWidth + 'rem'
      }}
    >
      <div
        class={
          'w-full h-11 shadow-content overflow-hidden max-w-[90vw] transition-all flex justify-between items-center gap-4 ' +
          (search.focus ? 'bg-white/60' : 'bg-white/40 hover:bg-white/60')
        }
        style={{
          borderRadius: settings.state.searchRadius + 'px'
        }}
      >
        <div
          class="w-11 h-11 flex justify-center items-center"
          onClick={() => {
            search.showSearchConfig = true
          }}
        >
          <div class="p-2 rounded-full overflow-hidden bg-white/40 cursor-pointer">
            <div
              class="w-4 h-4 bg-center bg-contain bg-no-repeat"
              style={{ backgroundImage: `url('${searchConfig.current.icon}')` }}
            />
          </div>
        </div>
        <input
          v-model={search.searchStr}
          ref={(el) => (search.searchRef = el as any)}
          onContextmenu={(e) => e.stopPropagation()}
          class="flex-1 h-full outline-none bg-transparent placeholder:text-slate-600 placeholder:tracking-widest text-slate-800 pr-4"
          placeholder={`输入搜索 ${searchConfig.current.name}`}
        />
      </div>
      <Transition name="searchContent">{search.showSearchConfig && <SearchConfig />}</Transition>
      <Transition name="searchContent">
        {search.focus && !search.searchStr && searchConfig.history.length > 0 && <SearchHistory />}
      </Transition>
      <Transition name="searchContent">
        {search.focus && search.searchStr && <SearchSuggestion />}
      </Transition>
    </div>
  )
})
