import { apiBase, cdnBase } from '@/config'
import { UAParser } from 'ua-parser-js'
const ua = new UAParser(navigator.userAgent)
// 设备型号：例如 Mac Os-Chrome
const device = ua.getOS().name + '-' + ua.getBrowser().name

/**
 * 发送请求
 * @param method
 * @param url
 * @param requestConfig
 */
export default function request<R>(
  method: 'GET' | 'POST' | 'PUT' | 'PATCH' | 'DELETE',
  url: `${'/api' | '/cdn'}${string}`,
  requestConfig?: {
    data?: any
    dataType?: 'json' | 'form'
    returnType?: 'json' | 'text' | 'blob'
  }
) {
  const { data, dataType = 'json', returnType = 'json' } = requestConfig || {}
  const fp = localStorage.getItem('fp') || ''
  const config: any = {
    method,
    headers: {
      Authorization: 'Bearer ' + localStorage.getItem('token'),
      device,
      fp
    }
  }
  if (!['GET', 'DELETE'].includes(method)) {
    if (dataType === 'json') {
      config.body = JSON.stringify(data)
      config.headers['Content-Type'] = 'application/json'
    } else {
      config.body = new FormData()
      for (const key in data) {
        config.body.append(key, data[key])
      }
    }
  }
  const path = url.replace(/^\/api/, apiBase).replace(/^\/cdn/, cdnBase)
  return fetch(path, config).then((res) => {
    if (res.status >= 200 && res.status < 400) {
      return res[returnType]()
    } else {
      return res.text().then((err) => {
        if (res.status === 401) {
          localStorage.setItem('token', '')
          return Promise.reject('登录已过期，请重新登录')
        }
        return Promise.reject(err)
      })
    }
  }) as Promise<R>
}
